SWDEV-503089 - Fix and enable disabled HIP tests from math group (#1319)

* SWDEV-503089 - Fix and enable disabled HIP tests from math group

* SWDEV-503089 - Move single precision reduced run to a common function
This commit is contained in:
amilanov-amd
2025-11-26 10:34:05 +01:00
committed by GitHub
parent ee48f6221d
commit da9bb4efae
28 changed files with 313 additions and 575 deletions
@@ -123,9 +123,9 @@ class Dummy {
__device__ ~Dummy() {}
};
__global__ void fdividef_kernel_v1(float* x, float y) { float result = fdividef(x, y); }
__global__ void fdividef_kernel_v2(Dummy x, float y) { float result = fdivide(x); }
__global__ void fdividef_kernel_v3(float x, float* y) { float result = fdivide(x); }
__global__ void fdividef_kernel_v4(float x, Dummy y) { float result = fdivide(x); }
__global__ void fdividef_kernel_v2(Dummy x, float y) { float result = fdividef(x, y); }
__global__ void fdividef_kernel_v3(float x, float* y) { float result = fdividef(x, y); }
__global__ void fdividef_kernel_v4(float x, Dummy y) { float result = fdividef(x, y); }
)"};
static constexpr auto kIsFinite{R"(